#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-expand-syns
version:              0.4.12.0
visibility:           public
id:                   th-expand-syns-0.4.12.0-9FyBcuZG88EFZMLYopcTca
key:                  th-expand-syns-0.4.12.0-9FyBcuZG88EFZMLYopcTca
license:              BSD-3-Clause
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Daniel Schüssler
homepage:             https://github.com/DanielSchuessler/th-expand-syns
synopsis:             Expands type synonyms in Template Haskell ASTs
description:
    Expands type synonyms in Template Haskell ASTs.

    As of version @0.4.9.0@, this library is a small shim on
    top of the @applySubstitution@/@resolveTypeSynonyms@
    functions from @th-abstraction@, so you may want to
    consider using @th-abstraction@ instead.

category:             Template Haskell
abi:                  fde8c8287aabf1b439845b7ec320fdba
exposed:              True
exposed-modules:      Language.Haskell.TH.ExpandSyns
import-dirs:          /usr/lib/ghc-9.6.6/site-local/th-expand-syns-0.4.12.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/th-expand-syns-0.4.12.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/th-expand-syns-0.4.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-expand-syns
hs-libraries:         HSth-expand-syns-0.4.12.0-9FyBcuZG88EFZMLYopcTca
depends:
    base-4.18.2.1 containers-0.6.7 syb-0.7.3-H7QXegMKksQGc4JgI4csk0
    template-haskell-2.20.0.0
    th-abstraction-0.6.0.0-6nwiZFs5BlM71phLjoyZV3

haddock-interfaces:
    /usr/share/doc/haskell-th-expand-syns/html/th-expand-syns.haddock

haddock-html:         /usr/share/doc/haskell-th-expand-syns/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

